#
# spec file for package python-gspread
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-gspread
Version:        3.1.0
Release:        bp154.1.26
Summary:        Google Spreadsheets Python API
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/burnash/gspread
Source:         https://github.com/burnash/gspread/archive/v%{version}.tar.gz
BuildRequires:  %{python_module betamax}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module oauth2client}
BuildRequires:  %{python_module requests >= 2.2.1}
BuildRequires:  %{python_module xml}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 2.2.1
BuildArch:      noarch
%python_subpackages

%description
A Python module to access Google Spreadsheets.

Features
--------

* Google Sheets API v4.
* Open a spreadsheet by its *title*, *url* or *key*.
* Select cells by labels, e.g. 'A1'.
* Extract range, entire row or column values.
* Python 3 support.

%prep
%setup -q -n gspread-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# needs betamax-json-body-serializer that does not exist on pypi anywhere
#%%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} nosetests-%{$python_bin_suffix} -v

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitelib}/*

%changelog
* Fri Mar 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.1.0:
  * Dropped Python 2.6 support
  * Fixed KeyError in urllib.quote in Python 2 (#605, #558)
  * Fixed Worksheet.title being out of sync after using update_title (#542 by @ryanpineo)
  * Fix parameter typos in docs (#616 by @bryanallen22)
  * Miscellaneous docs fixes (#604 by @dgilman)
  * Fixed typo in docs (#591 by @davidefiocco)
  * Added a method to copy spreadsheets (#625 by @dsask)
  * Added with_link attribute when sharing / adding permissions (#621 by @epicfaace)
  * Added ability to duplicate a worksheet (#617)
  * Change default behaviour of numericise function #499 (#502 by @danthelion)
  * Added stacklevel=2 to deprecation warnings
- Switch to github tarball for tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Jul 26 2018 jengelh@inai.de
- Trim bias from description.
* Thu May 24 2018 toddrme2178@gmail.com
- Update to 3.0.0
  * This version drops Google Sheets API v3 support.
    > API v4 was the default backend since version 2.0.0.
    > All v4-related code has been moved from `gspread.v4` module to `gspread` module.
- Update to 2.1.1
  * Fixed #533 (#534 by @reallistic)
- Update to 2.1.0
  * URL encode the range in the value_* functions (#530 by @aiguofer)
  * Open team drive sheets by name (#527 by @ryantuck)
- Update to 2.0.1
  * Fixed #518
  * Include v4 in setup.py
  * Fetch all spreadsheets in Spreadsheet.list_spreadsheet_files (#522 by @aiguofer)
- Update to 2.0.0
  * Ported the library to Google Sheets API v4.
    This is a transition release. The v3-related code is untouched,
    but v4 is used by default. It is encouraged to move to v4 since
    the API is faster and has more features.
    API v4 is a significant change from v3. Some methods are not
    backward compatible, so there's no support for this compatibility
    in gspread either.
    These methods and properties are not supported in v4:
    > `Spreadsheet.updated`
    > `Worksheet.updated`
    > `Worksheet.export()`
    > `Cell.input_value`
- Spec file cleanups
* Fri Sep  1 2017 alarrosa@suse.com
- Fixed Source url
* Fri Aug 18 2017 alarrosa@suse.com
- Update to python-gspread 0.6.2
  * See https://github.com/burnash/gspread/blob/master/HISTORY.rst
- Use singlespec macros
* Thu Sep  4 2014 toddrme2178@gmail.com
- Initial version
